// rf95_client.pde

#include <RH_RF95.h>
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>
#include "dtostrf.h"

// Singleton instance of the radio driver
RH_RF95 rf95(8, 3); // Adafruit Feather M0 with RFM95 

Adafruit_BME280 bme; // I2C

String datastring="";
char databuf[10];
uint8_t dataoutgoing[10];

void setup() 
{
  Serial.begin(9600);
  Serial.println(F("BME280 test"));

  bool status;
    
  // default settings
  // (you can also pass in a Wire library object like &Wire2)
  if (!bme.begin()) {
      Serial.println("Could not find a valid BME280 sensor, check wiring!");
      while (1);
  }

  if (!rf95.init())
    Serial.println("rf95 init failed");
}

void loop()
{
  // Read and print out the temperature, then convert to *F
  float c = bme.readTemperature();
  float f = c * 9.0 / 5.0 + 32;
  Serial.print("Temp: "); Serial.print(c); Serial.print("*C\t"); 
  Serial.print(f); Serial.println("*F");

  float h = bme.readHumidity();
  Serial.print("Humidity: ");
  Serial.print(h); Serial.println(" %");
    
  #define VBATPIN A7
       
  float measuredvbat = analogRead(VBATPIN);
  measuredvbat *= 2;    // we divided by 2, so multiply back
  measuredvbat *= 3.3;  // Multiply by 3.3V, our reference voltage
  measuredvbat /= 1024; // convert to voltage
  Serial.print("VBat: " ); Serial.println(measuredvbat);

  Serial.println("Sending to rf95_server");
  
  // Send a message to rf95_server
  uint8_t data[] = "Client 2";
  rf95.send(data, sizeof(data));
  rf95.waitPacketSent();
  
  uint8_t entry[] = "Temperature Sent";
  rf95.send(entry, sizeof(entry));
  rf95.waitPacketSent();

  datastring += dtostrf(f, 4, 2, databuf);
  strcpy((char *)dataoutgoing,databuf);
  Serial.println(databuf);
  rf95.send(dataoutgoing, sizeof(dataoutgoing));
  rf95.waitPacketSent();
  delay(400);

  uint8_t entry2[] = "Humidity Sent";
  rf95.send(entry2, sizeof(entry2));
  rf95.waitPacketSent();

  datastring += dtostrf(h, 4, 2, databuf);
  strcpy((char *)dataoutgoing,databuf);
  Serial.println(databuf);
  rf95.send(dataoutgoing, sizeof(dataoutgoing));
  rf95.waitPacketSent();
  delay(400);

  uint8_t entry3[] = "Battery Level";
  rf95.send(entry3, sizeof(entry3));
  rf95.waitPacketSent();

  datastring += dtostrf(measuredvbat, 4, 2, databuf);
  strcpy((char *)dataoutgoing,databuf);
  Serial.println(databuf);
  rf95.send(dataoutgoing, sizeof(dataoutgoing));
  rf95.waitPacketSent();
  delay(400);
  
  rf95.sleep();
  
  delay(10000);
}
